@@ -4,6 +4,7 @@ import traceback
 
 from json_log_formatter import VerboseJSONFormatter
 from logstash_async.handler import AsynchronousLogstashHandler
+from django.conf.settings import APP_LABEL
 
 
 class CustomisedJSONFormatter(VerboseJSONFormatter):
@@ -16,7 +17,7 @@ class CustomisedJSONFormatter(VerboseJSONFormatter):
         return {
             'message': message,
             'level': record.levelname,
-            'app': 'ras-main',
+            'app': APP_LABEL,
             **context
         }
 
